@@ -432,7 +432,7 @@ class RESTAPI :
 
             championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], summoner['id'])
             print(championMastery)
-            if len(championMastery) == [] :
+            if len(championMastery) == 0 :
                 api_url=URL['championmasteries'].format(url='/')
                 championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
                 print(championMastery)
